/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2009  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao.impl;

import java.lang.reflect.Method;
import java.util.List;
import java.util.Map;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Implemented by AutoDAO implementations.
 * <p/>
 * NOT FOR PUBLIC USE.
 */
public interface FinderExecutor {

  @NotNull
  <T> List<T> executeListFinder(@NotNull final Method method,
                                @NotNull final Map<String, ?> namedArgs,
                                @Nullable final Integer limit,
                                @Nullable final Integer offset);

  /**
   * Execute a finder method with the appropriate arguments.
   * @param method      query method.
   * @param indexedArgs arguments for query method
   * @param limit       query limit. Can be <code>null</code>. See {@link net.sf.autodao.Limit}.
   * @param offset      query offset. Can be <code>null</code>. See {@link net.sf.autodao.Offset}.
   * @return list of found objects or empty list.
   */
  @NotNull
  <T> List<T> executeListFinder(@NotNull final Method method,
                                @NotNull final Object[] indexedArgs,
                                @Nullable final Integer limit,
                                @Nullable final Integer offset);

  @Nullable
  <T> T executeSingleFinder(@NotNull final Method method, @NotNull final Map<String, ?> namedArgs);

  /**
   * Same as {@link #executeListFinder(Method, Object[], Integer, Integer)} but for single result.
   * @param method      query method.
   * @param indexedArgs arguments for query method.
   * @return found object or <code>null</code>
   */
  @Nullable
  <T> T executeSingleFinder(@NotNull final Method method, @NotNull final Object[] indexedArgs);
}
