/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2009  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao.impl;

import java.lang.reflect.Method;

/**
 * Exception that is thrown when AutoDAO interface violates any rules. This exception indicates programming error, it
 * should never be caught.
 * <p/>
 * NOT FOR PUBLIC USE.
 */
public final class SpecificationViolationException extends RuntimeException {

  /**
   * Constructor.
   * @param message error message.
   * @param meth    invalid method.
   */
  public SpecificationViolationException(final String message, final Method meth) {
    this(message, meth, null);
  }

  public SpecificationViolationException(final String message, final Method meth, final Throwable cause) {
    super("AutoDAO specification violation in " + meth + ": " + message, cause);
  }
}
